irfftn

Function irfftn 

pub fn irfftn(a: impl AsRef<Array>, options: FftnOptions) -> Result<Array>
The inverse of rfftn().

Note the input is generally complex. The dimensions of the input specified in axes are padded or truncated to match the sizes from s. The last axis in axes is treated as the real axis and will have size s[s.len()-1] // 2 + 1.

Params

  • a: The input array.
  • options: Transform lengths and axes. The default transforms all axes at their input sizes.