rfftn

Function rfftn 

pub fn rfftn(a: impl AsRef<Array>, options: FftnOptions) -> Result<Array>
n-dimensional real discrete Fourier Transform.

The output has the same shape as the input except along the dimensions in axes in which case it has sizes from s. The last axis in axes is treated as the real axis and will have size s[s.len()-1] // 2 + 1.

Params

  • a: The input array. If the array is complex it will be silently cast to a real type.
  • options: Transform lengths and axes. The default transforms all axes at their input sizes.